@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Getopt::Kingpin::Base -base;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 has _placeholder => undef;
 has _hidden      => 0;
@@ -35,13 +35,27 @@ sub help_str {
         $ret->[0] = sprintf "-%s", $self->short_name;
     }
 
+    my $default = $self->_default;
+    my $printable_default = defined $default;
+    if (ref $default) {
+        $printable_default = Scalar::Util::blessed($default) && overload::Method($default, q[""]);
+    }
+
     if ($self->type eq "Bool") {
         $ret->[1] = sprintf "--%s", $self->name;
+    } elsif ($self->is_hash) {
+        if (defined $self->_placeholder and $self->_placeholder =~ /=/) {
+            $ret->[1] = sprintf '--%s %s', $self->name, $self->_placeholder;
+        } elsif (defined $self->_placeholder) {
+            $ret->[1] = sprintf '--%s KEY=%s', $self->name, $self->_placeholder;
+        } else {
+            $ret->[1] = sprintf "--%s KEY=VALUE", $self->name;
+        }
     } else {
         if (defined $self->_placeholder) {
             $ret->[1] = sprintf '--%s=%s', $self->name, $self->_placeholder;
-        } elsif (defined $self->_default) {
-            $ret->[1] = sprintf '--%s="%s"', $self->name, $self->_default;
+        } elsif ($printable_default) {
+            $ret->[1] = sprintf '--%s="%s"', $self->name, $default;
         } else {
             $ret->[1] = sprintf "--%s=%s", $self->name, uc $self->name;
         }
