@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 sub set_value {
     my $self = shift;
@@ -33,14 +33,13 @@ Getopt::Kingpin::Type::Bool - command line option object
 
 =head1 DESCRIPTION
 
-Getopt::Kingpin::Type::Bool は、Getopt::Kingpin内で使用する型定義です。
+Getopt::Kingpin::Type::Bool is the type definition for Bool within Getopt::Kingpin.
 
 =head1 METHOD
 
 =head2 set_value($value)
 
-$self->valueに値を設定します。
-値は0 or 非0のみです。
+Set the value of $self->value.
 
 =head1 LICENSE
 
