@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Path::Tiny;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 sub set_value {
     my $self = shift;
@@ -41,15 +41,14 @@ Getopt::Kingpin::Type::ExistingFileOrDir - command line option object
 
 =head1 DESCRIPTION
 
-Getopt::Kingpin::Type::ExistingFileOrDir は、Getopt::Kingpin内で使用する型定義です。
+Getopt::Kingpin::Type::ExistingFileOrDir is the type definition for ExistingFileOrDir within Getopt::Kingpin.
 
 =head1 METHOD
 
 =head2 set_value($value)
 
-$self->valueに値を設定します。
-値は、Path::Tinyによって処理されます。
-必ず存在するfileもしくはdirectoryである必要があります。
+Set the value of $self->value. Converts strings to Path::Tiny objects and
+checks C<exists> is true.
 
 =head1 LICENSE
 
